{lib, ...}: let
  host = "127.0.0.1";
  port = 8989;
in {
  config.microvm.autostart = ["sonarr"];

  config.system.activationScripts.makeSonarrDir = lib.stringAfter ["var"] ''
    mkdir -p /var/lib/sonarr
  '';

  config.microvm.vms."sonarr" = {
    config = {
      system.stateVersion = "24.11";
      microvm.shares = [
        {
          tag = "ro-store";
          source = "/nix/store";
          mountPoint = "/nix/.ro-store";
        }
        {
          tag = "data-dir";
          source = "/var/lib/sonarr";
          mountPoint = "/var/lib/sonarr";
        }
      ];
      microvm.interfaces = [
        {
          type = "tap";

          # interface name on the host
          id = "vm-sonarr";

          # Ethernet address of the MicroVM's interface, not the host's
          #
          # Locally administered have one of 2/6/A/E in the second nibble.
          mac = "02:00:00:00:00:01";
        }
      ];

      services.sonarr = {
        enable = true;
        openFirewall = true; # Hide sonarr behind firewall
      };

      services.nginx.virtualHosts."sonarr.spoodythe.one" = {
        addSSL = true;
        enableACME = true;
        locations."/" = {
          proxyPass = "http://${host}:${toString port}";
        };
      };
    };
  };
}
